#cs ----------------------------------------------------------------------------

 AutoIt Version: 3.3.14.2
 Author:         myName

 Script Function:
	Template AutoIt script.

#ce ----------------------------------------------------------------------------

; Script Start - Add your code below here
; #FUNCTION# ====================================================================================================================
; Name...........: _String_MultiReplace
; Description ...: Replace different letters with different letters/text in one pass
; Syntax.........: _String_MultiReplace($String, $Search, $Replace, $Separator)
; Parameters ....: $String            - A string
;                  $Searcharray       - An array or a string with letters to find
;                  $Replacearray      - An array or a string with letters/text to replace with
;                  $SearchSeparator   - If $Search is a string, the letters to find are separated by $SearchSeparator
;                  $ReplaceSeparator  - If $Replace is a string, the letters to replace with are separated by $ReplaceSeparator
; Return values .: Success            - Returns the new string
;                                     - @extended contains the number of replacements
;                  Failure            - 0: The Parameter $Search isn't used with an array or a string
;                                     - 1: The Parameter $Replace isn't used with an array or a string
;                                     - 2: The Parameters $Search and $Replace have different sizes or the Parameters
;                                          $SearchSeparator/$ReplaceSeparator are wrong
;                                     - If return value = 0, 1 or 2, @extended = 0
; Remarks:         If $Search is a string, the letters to find have to be separated by a separator character
;                  If $Replace is a string, the letters to replace with have to be separated by a separator char
; Author ........: NO1 :-)
; Related .......: StringRegExpReplace, StringReplace
; Example .......: Yes
; ===============================================================================================================================


Func _String_MultiReplace($String, $Search, $Replace, $SearchSeparator = "|", $ReplaceSeparator = "|")
	Local $SearchType = 0, $ReplaceType = 0, $SearchSingleChar = "", $ReplaceSingleChar = "", $ReturnString = "", $CharAdded = 0, $CountReplacements = 0
	If IsArray($Search) = True Then
		$SearchType = 1
	ElseIf IsString($Search) = True Then
		$SearchType = 2
		$SearchSingleChar = StringSplit($Search, $SearchSeparator)
	Else
		Return 0
	EndIf
	If IsArray($Replace) = True Then
		$ReplaceType = 1
	ElseIf IsString($Replace) = True Then
		$ReplaceType = 2
		$ReplaceSingleChar = StringSplit($Replace, $ReplaceSeparator)
	Else
		Return 1
	EndIf
	If $SearchType = 1 And $ReplaceType = 1 Then
		If UBound($Search) <> UBound($Replace) Then
		    Return 2
		EndIf
	ElseIf $SearchType = 2 And $ReplaceType = 2 Then
		If $SearchSingleChar[0] <> $ReplaceSingleChar[0] Then
			Return 2
		EndIf
	ElseIf $SearchType = 1 And $ReplaceType = 2 Then
		If UBound($Search) <> $ReplaceSingleChar[0] Then
			Return 2
		EndIf
	ElseIf $SearchType = 2 And $ReplaceType = 1 Then
		If $SearchSingleChar[0] <> UBound($Replace) Then
			Return 2
		EndIf
	EndIf
	$SingleChar = StringSplit($String, "")
	For $i = 1 To $SingleChar[0]
		If $SearchType = 1 And $ReplaceType = 1 Then
    	    For $j = 0 To UBound($Search)-1
		        If $SingleChar[$i] == $Search[$j] Then
		    		$ReturnString &= $Replace[$j]
		    		$CharAdded = 1
					$CountReplacements += 1
		    	Else
			    	If $j = UBound($Search)-1 And $CharAdded = 0 Then
			    	    $ReturnString &= $SingleChar[$i]
			    	EndIf
			    EndIf
		    Next
		    $CharAdded = 0
		ElseIf $SearchType = 2 And $ReplaceType = 2 Then
			For $j = 1 To $SearchSingleChar[0]
				If $SingleChar[$i] == $SearchSingleChar[$j] Then
					$ReturnString &= $ReplaceSingleChar[$j]
					$CharAdded = 1
					$CountReplacements += 1
				Else
					If $j = $SearchSingleChar[0] And $CharAdded = 0 Then
						$ReturnString &= $SingleChar[$i]
					EndIf
				EndIf
			Next
			$CharAdded = 0
		ElseIf $SearchType = 1 And $ReplaceType = 2 Then
    	    For $j = 0 To UBound($Search)-1
		        If $SingleChar[$i] == $Search[$j] Then
		    		$ReturnString &= $ReplaceSingleChar[$j+1]
		    		$CharAdded = 1
					$CountReplacements += 1
		    	Else
			    	If $j = UBound($Search)-1 And $CharAdded = 0 Then
			    	    $ReturnString &= $SingleChar[$i]
			    	EndIf
			    EndIf
		    Next
		    $CharAdded = 0
		ElseIf $SearchType = 2 And $ReplaceType = 1 Then
			For $j = 1 To $SearchSingleChar[0]
				If $SingleChar[$i] == $SearchSingleChar[$j] Then
					$ReturnString &= $Replace[$j-1]
					$CharAdded = 1
					$CountReplacements += 1
				Else
					If $j = $SearchSingleChar[0] And $CharAdded = 0 Then
						$ReturnString &= $SingleChar[$i]
					EndIf
				EndIf
			Next
			$CharAdded = 0
		EndIf
	Next
	SetExtended($CountReplacements)
	Return $ReturnString
EndFunc